@@ -21,16 +21,19 @@ import System.Posix.Files
 #endif
 import Control.Exception
 import Data.List
+import System.FilePath (pathSeparator)
+
+sep = map (\c -> if c == '/' then pathSeparator else c)
 
 bp = "testtmp"
-touch x = writeFile x ""
+touch x = writeFile (sep x) ""
 
 globtest thetest = 
     bracket_ (setupfs)
              (recursiveRemove SystemFS bp)
              thetest
     where setupfs =
-              do mapM_ (\x -> createDirectory x)
+              do mapM_ (\x -> createDirectory (sep x))
                        [bp, bp ++ "/a", bp ++ "/aab", bp ++ "/aaa",
                         bp ++ "/ZZZ", bp ++ "/a/bcd",
                         bp ++ "/a/bcd/efg"]
@@ -47,7 +50,7 @@ eq msg exp res =
     assertEqual msg (sort exp) (sort res)
 mf msg func = TestLabel msg $ TestCase $ globtest func
 f func = TestCase $ globtest func
-preppath x = bp ++ "/" ++ x
+preppath x = sep (bp ++ "/" ++ x)
 
 test_literal =
     map f
